==> linuxconf-1.20.src.tar.gz: linuxconf-1.20/modules/fetchmailconf/fetchmailconf.pm <==
/* _dict.cc 12/12/1999 22.28.00 */
/* api_status.cc 06/12/1999 18.50.26 */
/* basicsedit.cc 27/01/2000 12.16.56 */
PRIVATE void BASICS::init (void);
PUBLIC BASICS::BASICS (const char *s);
PUBLIC int BASICS::write (void);
PUBLIC void BASICS::execute (void);
PUBLIC int BASICS::edit (void);
PUBLIC void BASICS::read (void);
PUBLIC int BASICS::probe (int level, int target, int simulation);
PUBLIC DAEMON_FETCHMAIL::DAEMON_FETCHMAIL (void);
PUBLIC PROC *DAEMON_FETCHMAIL::getdaemonprocess (void);
PUBLIC int DAEMON_FETCHMAIL::killdaemon (void);
PUBLIC int DAEMON_FETCHMAIL::startdaemon (int daemon);
/* comng.cc 25/01/2000 11.46.36 */
PUBLIC FETCHMAIL_COMNG::FETCHMAIL_COMNG (DICTIONARY&_dict);
PUBLIC void FETCHMAIL_COMNG::setupdia (DIALOG&dia);
PUBLIC int FETCHMAIL_COMNG::validate (DIALOG&dia, int &nof);
PUBLIC int FETCHMAIL_COMNG::save (PRIVILEGE *privilege);
PUBLIC int FETCHMAIL_COMNG::deluser (PRIVILEGE *privilege);
/* fetchmailconf.cc 04/08/2000 13.11.58 */
PUBLIC MODULE_fetchmailconf::MODULE_fetchmailconf (void);
PUBLIC void MODULE_fetchmailconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_fetchmailconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_fetchmailconf::dohtml (const char *key);
PUBLIC int MODULE_fetchmailconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_fetchmailconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_fetchmailconf::execmain (int argc, char *argv[]);
PUBLIC int MODULE_fetchmailconf::probe (int level,
	 int target,
	 bool simulation);
/* keyword.cc 12/12/1999 22.28.00 */
PRIVATE void KEYWORD::init (void);
PUBLIC void KEYWORD::init (KEYWORD *keyword);
PUBLIC KEYWORD::KEYWORD (void);
PUBLIC KEYWORD *KEYWORDLIST::getitem (int no)const;
PUBLIC KEYWORD *KEYWORDLIST::getitem (const char *_keyword)const;
PUBLIC KEYWORDLIST::KEYWORDLIST (void);
PUBLIC void KEYWORDLIST::clean_option (void);
PRIVATE char *KEYWORDLIST::next_word (char *d,
	 const char *s,
	 int size);
PUBLIC KEYWORD *KEYWORDLIST::option (char *word,
	 const char *config,
	 int size);
/* serveredit.cc 07/08/2000 11.06.14 */
PRIVATE void SERVER::init (void);
PUBLIC SERVER::SERVER (const char *_server_name);
PUBLIC SERVER::SERVER (void);
PUBLIC int SERVER::write (int button);
PUBLIC void SERVER::write_item (FILE_CFG *fout, VIEWITEM *item);
PUBLIC int SERVER::write_server (FILE_CFG *fout);
PUBLIC int SERVER::edit (void);
PUBLIC bool SERVER::input_error (void);
PUBLIC SERVER *SERVERLIST::getitem (int no)const;
PUBLIC SERVER *SERVERLIST::getitem (const char *server_name)const;
PUBLIC SERVERLIST::SERVERLIST (void);
PUBLIC void SERVERLIST::read (void);
PUBLIC int SERVERLIST::edit (void);
PUBLIC SERVER *SERVERLIST::select (void);
/* useridedit.cc 07/08/2000 11.07.50 */
PRIVATE void USERID::init (void);
PUBLIC USERID::USERID (const char *_remote_user);
PUBLIC USERID::USERID (void);
PUBLIC int USERID::write (int button);
PUBLIC void USERID::write_item (FILE_CFG *fout, VIEWITEM *item);
PUBLIC int USERID::write_userid (FILE_CFG *fout);
PUBLIC void USERID::print_line (char *word, FILE_CFG *fout);
PUBLIC int USERID::edit (void);
PUBLIC bool USERID::input_error (void);
PUBLIC USERID *USERIDLIST::getitem (int no)const;
PUBLIC USERID *USERIDLIST::getitem (const char *local_user)const;
PUBLIC USERIDLIST::USERIDLIST (void);
PUBLIC void USERIDLIST::read (SERVER *server);
PUBLIC void USERIDLIST::read_users (KEYWORDLIST *keywordlist,
	 KEYWORD *keyword,
	 char *word,
	 SERVER *server);
PUBLIC int USERIDLIST::edit (SERVER *server);

==> linuxconf-1.26r2.src.tar.gz: linuxconf-1.26r2/modules/fetchmailconf/fetchmailconf.pm <==
/* _dict.cc 12/12/1999 22.28.00 */
/* api_status.cc 06/12/1999 18.50.26 */
/* basicsedit.cc 27/01/2000 12.16.56 */
PRIVATE void BASICS::init (void);
PUBLIC BASICS::BASICS (const char *s);
PUBLIC int BASICS::write (void);
PUBLIC void BASICS::execute (void);
PUBLIC int BASICS::edit (void);
PUBLIC void BASICS::read (void);
PUBLIC int BASICS::probe (int level, int target, int simulation);
PUBLIC DAEMON_FETCHMAIL::DAEMON_FETCHMAIL (void);
PUBLIC PROC *DAEMON_FETCHMAIL::getdaemonprocess (void);
PUBLIC int DAEMON_FETCHMAIL::killdaemon (void);
PUBLIC int DAEMON_FETCHMAIL::startdaemon (int daemon);
/* comng.cc 25/01/2000 11.46.36 */
PUBLIC FETCHMAIL_COMNG::FETCHMAIL_COMNG (DICTIONARY&_dict);
PUBLIC void FETCHMAIL_COMNG::setupdia (DIALOG&dia);
PUBLIC int FETCHMAIL_COMNG::validate (DIALOG&dia, int &nof);
PUBLIC int FETCHMAIL_COMNG::save (PRIVILEGE *privilege);
PUBLIC int FETCHMAIL_COMNG::deluser (PRIVILEGE *privilege);
/* fetchmailconf.cc 28/08/2000 18.12.26 */
PUBLIC MODULE_fetchmailconf::MODULE_fetchmailconf (void);
PUBLIC void MODULE_fetchmailconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_fetchmailconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_fetchmailconf::dohtml (const char *key);
PUBLIC int MODULE_fetchmailconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_fetchmailconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_fetchmailconf::execmain (int argc,
	 char *argv[],
	 bool);
PUBLIC int MODULE_fetchmailconf::probe (int level,
	 int target,
	 bool simulation);
/* keyword.cc 12/12/1999 22.28.00 */
PRIVATE void KEYWORD::init (void);
PUBLIC void KEYWORD::init (KEYWORD *keyword);
PUBLIC KEYWORD::KEYWORD (void);
PUBLIC KEYWORD *KEYWORDLIST::getitem (int no)const;
PUBLIC KEYWORD *KEYWORDLIST::getitem (const char *_keyword)const;
PUBLIC KEYWORDLIST::KEYWORDLIST (void);
PUBLIC void KEYWORDLIST::clean_option (void);
PRIVATE char *KEYWORDLIST::next_word (char *d,
	 const char *s,
	 int size);
PUBLIC KEYWORD *KEYWORDLIST::option (char *word,
	 const char *config,
	 int size);
/* serveredit.cc 23/08/2000 01.36.48 */
PRIVATE void SERVER::init (void);
PUBLIC SERVER::SERVER (const char *_server_name);
PUBLIC SERVER::SERVER (void);
PUBLIC int SERVER::write (int button);
PUBLIC void SERVER::write_item (FILE_CFG *fout,
	 const VIEWITEMS&items,
	 VIEWITEM *item,
	 bool comments_only);
PUBLIC int SERVER::write_server (FILE_CFG *fout);
PUBLIC int SERVER::edit (void);
PUBLIC bool SERVER::input_error (void);
PUBLIC SERVER *SERVERLIST::getitem (int no)const;
PUBLIC SERVER *SERVERLIST::getitem (const char *server_name)const;
PUBLIC SERVERLIST::SERVERLIST (void);
PUBLIC void SERVERLIST::read (void);
PUBLIC int SERVERLIST::edit (void);
PUBLIC SERVER *SERVERLIST::select (void);
/* useridedit.cc 23/08/2000 01.36.48 */
PRIVATE void USERID::init (void);
PUBLIC USERID::USERID (const char *_remote_user);
PUBLIC USERID::USERID (void);
PUBLIC int USERID::write (int button);
PUBLIC void USERID::write_item (FILE_CFG *fout,
	 const VIEWITEMS&items,
	 VIEWITEM *item,
	 bool comments_only);
PUBLIC int USERID::write_userid (FILE_CFG *fout);
PUBLIC void USERID::print_line (char *word, FILE_CFG *fout);
PUBLIC int USERID::edit (void);
PUBLIC bool USERID::input_error (void);
PUBLIC USERID *USERIDLIST::getitem (int no)const;
PUBLIC USERID *USERIDLIST::getitem (const char *local_user)const;
PUBLIC USERIDLIST::USERIDLIST (void);
PUBLIC void USERIDLIST::read (SERVER *server);
PUBLIC void USERIDLIST::read_users (KEYWORDLIST *keywordlist,
	 KEYWORD *keyword,
	 char *word,
	 SERVER *server);
PUBLIC int USERIDLIST::edit (SERVER *server);
